"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadBuildContext = void 0;
const tslib_1 = require("tslib");
const node_path_1 = require("node:path");
const pkg_types_1 = require("pkg-types");
const types_1 = require("../types");
const config_1 = require("./config");
const npm_1 = require("./npm");
const loadBuildContext = (cwd, command, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const pkg = yield (0, npm_1.loadPackageJSON)();
    const workspace = yield (0, pkg_types_1.findWorkspaceDir)();
    const config = yield (0, config_1.loadConfig)(pkg);
    return {
        cli: {
            command,
            isDev: command === types_1.COMMAND.DEV,
            isAnalyze: command === types_1.COMMAND.ANALYZE,
            isBuild: command === types_1.COMMAND.BUILD,
            isTest: command === types_1.COMMAND.TEST,
            isRun: command === types_1.COMMAND.RUN,
            isLint: command === types_1.COMMAND.LINT,
            options,
        },
        env: {
            isCI: !!process.env.CI,
        },
        dirs: {
            cwd,
            workspace,
        },
        resolve: {
            alias: {
                pbc: (0, node_path_1.resolve)(cwd, './src/pbc'),
            },
        },
        pkg,
        config,
        enable: {
            apiExtractor: (0, npm_1.tryRequire)('./api-extractor', cwd),
            cemAnalyzer: (0, npm_1.tryRequire)('./custom-elements-manifest.config', cwd),
            mft: (0, npm_1.tryRequire)('./federation.config'),
        },
    };
});
exports.loadBuildContext = loadBuildContext;
