"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startShell = exports.runAsync = exports.run = void 0;
const tslib_1 = require("tslib");
const node_child_process_1 = require("node:child_process");
const node_path_1 = require("node:path");
const consola_1 = tslib_1.__importDefault(require("consola"));
const run = (cwd, command, options = {}) => {
    const { exitOnError = true, 
    // defaulting to true for Windows support
    prefixCommandWithNode = true, env = Object.assign({}, process.env), nodeArgs = '', verbose = true, } = options;
    const fullCommand = prefixCommandWithNode ? `node ${nodeArgs} ${command}` : command;
    const result = (0, node_child_process_1.spawnSync)(fullCommand, {
        shell: true,
        cwd,
        stdio: verbose ? 'inherit' : 'ignore',
        env,
    });
    if (result.status === 1 && exitOnError) {
        process.exit(result.status);
    }
    return result;
};
exports.run = run;
const normaliseNPMCLI = (cli) => {
    if (cli.toLowerCase() === 'npm') {
        return process.platform.match(/^win/) ? 'npm.cmd' : 'npm';
    }
    return cli;
};
const runAsync = (cwd, command, options = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { exitOnError = true, prefixCommandWithNode = true, env = Object.assign({}, process.env), nodeArgs = '', verbose = true, } = options;
    return new Promise((resolve, reject) => {
        const chunks = command.trim().split(' ');
        const fullCommand = prefixCommandWithNode
            ? `node ${nodeArgs} ${chunks.shift()}`
            : chunks.shift();
        const crossPlatformCommand = normaliseNPMCLI(fullCommand);
        const child = (0, node_child_process_1.spawn)(crossPlatformCommand, chunks, {
            cwd,
            stdio: verbose ? 'inherit' : 'ignore',
            env,
        });
        child.on('close', (code) => {
            if (code === 0) {
                resolve(null);
            }
            else {
                const err = new Error(`Unexpected error executing ${command}`);
                if (exitOnError) {
                    consola_1.default.error(err);
                    return process.exit(code);
                }
                reject(err);
            }
        });
        child.on('error', (err) => {
            if (exitOnError) {
                consola_1.default.error(err);
                return process.exit(1);
            }
            reject(err);
        });
    });
});
exports.runAsync = runAsync;
// Based on https://github.com/unjs/giget/blob/main/src/_utils.ts#L110
const currentShell = () => {
    if (process.env.SHELL) {
        return process.env.SHELL;
    }
    if (process.platform === 'win32') {
        return 'cmd.exe';
    }
    return '/bin/bash';
};
const startShell = (cwd) => {
    cwd = (0, node_path_1.resolve)(cwd);
    const shell = currentShell();
    consola_1.default.info(`(experimental) Opening shell in ${(0, node_path_1.relative)(process.cwd(), cwd)}...`);
    // spawnSync command is quoted to support paths with spaces on Windows (C:/Program Files etc.)
    (0, node_child_process_1.spawnSync)(`"${shell}"`, [], {
        cwd,
        shell: true,
        stdio: 'inherit',
        env: Object.assign(Object.assign({}, process.env), { 
            // DEBUG (set via log-level) messes up zsh
            DEBUG: undefined }),
    });
};
exports.startShell = startShell;
