"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadConfig = void 0;
const tslib_1 = require("tslib");
const defu_1 = tslib_1.__importDefault(require("defu"));
const federation_1 = require("./federation");
const npm_1 = require("./npm");
const getDefaultConfig = (packageName) => ({
    app: {},
    builder: {
        default: 'webpack',
        dev: 'vite',
        lint: 'eslint-stylelint',
        test: 'uvu-playwright',
    },
    clean: !process.env.GENX_NO_CLEAN,
    copyAssets: ['**/*.{css,jpg,png,svg,mp4,ogg,webm}'],
    env: [
        'API_HOST',
        'DEFAULT_ORGANISATION',
        'DEFAULT_USER',
        'DEFAULT_PASSWORD',
        'ENABLE_SSO',
        'GENX.*',
        'GENX_*',
        'FORCE_HTTP',
        'SOCKET_EXT',
    ],
    federation: {
        name: (0, federation_1.getFederatedPkgName)(packageName),
    },
});
const readConfig = (packageJSON, path = './genx.config') => {
    const genxConfig = (0, npm_1.tryRequire)(path) || {};
    const packageJSONConfig = packageJSON.genx || {};
    const defaultConfig = getDefaultConfig(packageJSON.name);
    return (0, defu_1.default)(genxConfig, packageJSONConfig, defaultConfig);
};
const loadConfig = (packageJSON) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const config = readConfig(packageJSON);
    return Object.assign(Object.assign({}, config), { federation: yield (0, federation_1.resolveFederationConfig)(config.federation, packageJSON) });
});
exports.loadConfig = loadConfig;
