"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listAllFiles = exports.rename = exports.rm = void 0;
const tslib_1 = require("tslib");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
const rimraf_1 = require("rimraf");
/**
 * Deletes one or more provided paths
 */
const rm = (paths) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { 
// We can add support for globbing or filtering in the future
// See https://github.com/isaacs/rimraf#rimraff-opts---promise for all options
return (0, rimraf_1.rimraf)(paths); });
exports.rm = rm;
const rename = (oldPath, newPath) => (0, node_fs_1.renameSync)(oldPath, newPath);
exports.rename = rename;
const listAllFiles = (startPath, filter = (item) => true, mapper = (item) => item) => {
    const filenames = new Set();
    const walk = (dirPath) => {
        const files = (0, node_fs_1.readdirSync)(dirPath);
        for (const file of files) {
            const fullPath = (0, node_path_1.resolve)(dirPath, file);
            const stats = (0, node_fs_1.statSync)(fullPath);
            const isDir = stats.isDirectory();
            const base = (0, node_path_1.basename)(fullPath);
            const ext = isDir ? null : (0, node_path_1.extname)(fullPath).toLowerCase();
            const dir = (0, node_path_1.dirname)(fullPath);
            const entry = mapper({ path: fullPath, isDir, base, ext, dir, stats });
            if (filter(entry)) {
                if (isDir) {
                    walk(entry.path);
                }
                else {
                    filenames.add(entry.path);
                }
            }
        }
    };
    walk(startPath);
    return [...filenames];
};
exports.listAllFiles = listAllFiles;
