"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerPartial = exports.renderFile = exports.render = void 0;
const tslib_1 = require("tslib");
const node_fs_1 = require("node:fs");
const change_case_1 = require("change-case");
const handlebars_1 = tslib_1.__importDefault(require("handlebars"));
/*
| Method            | Result      |
| ----------------- | ----------- |
| `camelCase`       | `twoWords`  |
| `capitalCase`     | `Two Words` |
| `constantCase`    | `TWO_WORDS` |
| `dotCase`         | `two.words` |
| `kebabCase`       | `two-words` |
| `lowerCase`       | `two words` |
| `pascalCase`      | `TwoWords`  |
| `pathCase`        | `two/words` |
| `sentenceCase`    | `Two words` |
| `snakeCase`       | `two_words` |
| `upperCase`       | `TWO_WORDS` |
*/
handlebars_1.default.registerHelper('camelCase', (s) => s && (0, change_case_1.camelCase)(s));
handlebars_1.default.registerHelper('capitalCase', (s) => s && (0, change_case_1.capitalCase)(s));
handlebars_1.default.registerHelper('constantCase', (s) => s && (0, change_case_1.constantCase)(s));
handlebars_1.default.registerHelper('dotCase', (s) => s && (0, change_case_1.dotCase)(s));
handlebars_1.default.registerHelper('kebabCase', (s) => s && (0, change_case_1.paramCase)(s));
handlebars_1.default.registerHelper('lowerCase', (s) => s && s.toLowerCase());
handlebars_1.default.registerHelper('pascalCase', (s) => s && (0, change_case_1.pascalCase)(s));
handlebars_1.default.registerHelper('pathCase', (s) => s && (0, change_case_1.pathCase)(s));
handlebars_1.default.registerHelper('sentenceCase', (s) => s && (0, change_case_1.sentenceCase)(s));
handlebars_1.default.registerHelper('snakeCase', (s) => s && (0, change_case_1.snakeCase)(s));
handlebars_1.default.registerHelper('upperCase', (s) => s && s.toUpperCase());
// plain functions should be used here - arrow functions break Handlebars context
// https://handlebarsjs.com/guide/#block-helpers
handlebars_1.default.registerHelper('ifEquals', function (arg1, arg2, options) {
    return arg1 === arg2 ? options.fn(this) : options.inverse(this);
});
handlebars_1.default.registerHelper('ifContains', function (source, substrings, options) {
    if (!source || !substrings)
        return options.inverse(this);
    const sourceString = JSON.stringify(source);
    const substrArray = Array.isArray(substrings) ? substrings : [substrings];
    const contains = substrArray.some((substring) => sourceString.includes(substring));
    return contains ? options.fn(this) : options.inverse(this);
});
handlebars_1.default.registerHelper('ifAny', function (...args) {
    const options = args.pop();
    const result = args.some((arg) => !!arg);
    return result ? options.fn(this) : options.inverse(this);
});
const render = (template, data) => handlebars_1.default.compile(template)(data);
exports.render = render;
const renderFile = (file, data, templateFile) => {
    const template = (0, node_fs_1.readFileSync)(templateFile || file, 'utf8');
    const output = (0, exports.render)(template, data);
    (0, node_fs_1.writeFileSync)(file, output, 'utf8');
};
exports.renderFile = renderFile;
const registerPartial = (name, templateFile) => {
    const template = (0, node_fs_1.readFileSync)(templateFile, 'utf8');
    handlebars_1.default.registerPartial(name, template);
};
exports.registerPartial = registerPartial;
