"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runSeedCommand = void 0;
const tslib_1 = require("tslib");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
const consola_1 = require("consola");
const types_1 = require("../types");
const child_process_1 = require("./child-process");
const console_1 = require("./console");
const seed_fetching_1 = require("./seed.fetching");
const seed_meta_1 = require("./seed.meta");
const seed_setup_1 = require("./seed.setup");
const runSeedCommand = (dirpath, options, command = types_1.COMMAND.INIT) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const dir = (0, node_path_1.resolve)(process.cwd(), dirpath);
    const start = Date.now();
    consola_1.consola.debug('CLI options', { dir, options, command });
    const isInit = command === types_1.COMMAND.INIT;
    const { insecure, seed, subdir, remote, ref, skipOptionalPrompts, params, isLogLevelVerbose, shell, scope, npm, skipInitDirCheck, skipSeedDepInstall, } = options;
    if (isLogLevelVerbose) {
        // Enables debug output in giget
        process.env.DEBUG = '1';
        // Debug level https://github.com/unjs/consola#log-level
        process.env.CONSOLA_LEVEL = '4';
        consola_1.consola.level = 4;
    }
    // don't overwrite if exists
    if (isInit && (0, node_fs_1.existsSync)(dir) && !skipInitDirCheck) {
        consola_1.consola.error(`Target directory ${(0, console_1.bold)(dir)} already exists.`);
        process.exit(1);
    }
    // for add operation there is no default seed - it needs to be specified explicitly
    if (!isInit && !seed) {
        consola_1.consola.error(`Please specify a seed.`);
        process.exit();
    }
    // fetch remote or copy local seed
    const result = yield (0, seed_fetching_1.fetchSeed)(seed, dir, remote, ref, insecure, subdir, isInit, npm, scope);
    consola_1.consola.debug('Seed fetched', result);
    // NPM install in .genx folder
    if (!skipSeedDepInstall) {
        yield (0, seed_setup_1.installSeedDeps)(result.extractedSeedGenxDir, isLogLevelVerbose);
    }
    const seedInfo = yield (0, seed_meta_1.loadSeed)(result.extractedSeedGenxDir);
    consola_1.consola.debug('Seed loaded', seedInfo);
    // run seed configure script
    yield (0, seed_setup_1.configureSeedApp)(seedInfo, result, params, dir, skipOptionalPrompts, isInit);
    const label = isInit ? 'created' : 'updated';
    consola_1.consola.success(`Project successfully ${label} in ${Date.now() - start}ms.`);
    // show next steps message if defined in seed details
    const nextStepsMessage = seedInfo.details.nextStepsMessage;
    if (nextStepsMessage === null || nextStepsMessage === void 0 ? void 0 : nextStepsMessage.length) {
        consola_1.consola.info(`Next steps: \n` + nextStepsMessage);
    }
    // launch shell in app dir
    if (shell) {
        (0, child_process_1.startShell)(dir);
    }
});
exports.runSeedCommand = runSeedCommand;
