"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadGenxModule = exports.loadSeed = void 0;
const tslib_1 = require("tslib");
const node_path_1 = require("node:path");
const consola_1 = require("consola");
const prompts_1 = require("./prompts");
// load seed details including prompt question defaults and validators
const loadSeed = (dir) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const GENX_RC = '.genxrc.js';
    const genxConfigPath = (0, node_path_1.resolve)(dir, GENX_RC);
    const { prompts, configure, details } = require(genxConfigPath);
    const defaults = yield (0, prompts_1.getPromptDefaults)(prompts());
    const validators = yield (0, prompts_1.getPromptValidators)(prompts());
    const validate = (data) => (0, prompts_1.validateSeedData)(data, validators, defaults);
    return {
        prompts: prompts(),
        configure: configure(),
        details: details(),
        defaults,
        validators,
        validate,
    };
});
exports.loadSeed = loadSeed;
const loadGenxModule = (genxDir, module = 'package.json', warnIfMissing = true) => {
    const path = (0, node_path_1.resolve)(genxDir, module);
    // require calls are cached by by default - ensuring we load the actual file on disk
    if (require.cache && require.cache[path]) {
        delete require.cache[path];
    }
    try {
        return require(path);
    }
    catch (e) {
        if (warnIfMissing) {
            consola_1.consola.warn(`Could not load ${module} from ${genxDir}`);
        }
        return {};
    }
};
exports.loadGenxModule = loadGenxModule;
