"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processOptions = exports.removeExclusions = exports.PROMPT_DATA_FILE = void 0;
const tslib_1 = require("tslib");
const node_fs_1 = require("node:fs");
const node_path_1 = require("node:path");
const consola_1 = require("consola");
const console_1 = require("./console");
const fs_1 = require("./fs");
const handlebars_1 = require("./handlebars");
const json_1 = require("./json");
const formatPersistedData = (data) => (Object.assign(Object.assign({}, data), { directory: (0, node_path_1.basename)(data.directory) }));
exports.PROMPT_DATA_FILE = 'answers.json';
const removeExclusions = (dir, exclusions) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    try {
        const exclude = (exclusions !== null && exclusions !== void 0 ? exclusions : []).map((x) => (0, node_path_1.resolve)(dir, x));
        yield Promise.all(exclude.map((exclusion) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            if ((0, node_fs_1.existsSync)(exclusion)) {
                yield (0, fs_1.rm)(exclusion);
                consola_1.consola.debug(`Excluded: ${exclusion}`);
            }
            else {
                consola_1.consola.debug(`Ignored invalid exclusion: ${exclusion}`);
            }
        })));
    }
    catch (err) {
        const error = process.env.DEBUG ? err : err.message;
        consola_1.consola.error(error);
        process.exit(1);
    }
});
exports.removeExclusions = removeExclusions;
const processItem = ({ base, dir: itemDir, path, isDir, ext, stats }, data, renamingEnabled, interpolationEnabled, interpolationWhitelist) => {
    const baseNew = (0, handlebars_1.render)(base, data);
    const needsRenaming = renamingEnabled && baseNew !== base;
    const pathNew = needsRenaming ? (0, node_path_1.resolve)(itemDir, baseNew) : path;
    if (needsRenaming) {
        try {
            (0, node_fs_1.renameSync)((0, node_path_1.resolve)(itemDir, base), (0, node_path_1.resolve)(itemDir, baseNew));
            consola_1.consola.debug(`Renamed ${(0, console_1.bold)(base)} to ${(0, console_1.bold)(baseNew)}`);
        }
        catch (e) {
            consola_1.consola.error(`Error renaming ${(0, console_1.bold)(base)} to ${(0, console_1.bold)(baseNew)}`);
        }
    }
    // Handlebars rendering
    if (interpolationEnabled && !isDir && interpolationWhitelist.some((i) => baseNew.includes(i))) {
        try {
            (0, handlebars_1.renderFile)(pathNew, data, pathNew);
            consola_1.consola.debug(`Interpolated variables in ${pathNew}`);
        }
        catch (e) {
            consola_1.consola.error(`Error interpolating variables in ${pathNew}`);
        }
    }
    return { isDir, ext, dir: itemDir, base: baseNew, path: pathNew, stats };
};
const processOptions = (fetchSeedResult, dir, data, isInit, persistedAnswers) => {
    var _a, _b;
    const options = ((_a = fetchSeedResult.pkg) === null || _a === void 0 ? void 0 : _a.genxSeedConfig) || {};
    consola_1.consola.debug('Seed options', JSON.stringify(options));
    if (options.processFiles) {
        const ignoreDirs = ((_b = options.processFiles) === null || _b === void 0 ? void 0 : _b.exclude) || [
            '.git',
            '.genx',
            '.github',
            'node_modules',
            '.gradle',
            'gradle',
        ];
        const filter = (entry) => !ignoreDirs.includes(entry.base);
        const mapper = (entry) => {
            var _a, _b, _c, _d, _e;
            return processItem(entry, data, !!((_a = options.processFiles) === null || _a === void 0 ? void 0 : _a.rename), !!((_c = (_b = options.processFiles) === null || _b === void 0 ? void 0 : _b.interpolateVariables) === null || _c === void 0 ? void 0 : _c.enabled), (_e = (_d = options.processFiles) === null || _d === void 0 ? void 0 : _d.interpolateVariables) === null || _e === void 0 ? void 0 : _e.include);
        };
        (0, fs_1.listAllFiles)(dir, filter, mapper);
    }
    if (options.persistAnswers) {
        const jsonPath = (0, node_path_1.resolve)(fetchSeedResult.genxDir, exports.PROMPT_DATA_FILE);
        const additions = persistedAnswers.additions || [];
        const persistedData = isInit
            ? data
            : Object.assign(Object.assign({}, persistedAnswers), { additions: [...additions, data] });
        (0, json_1.writeJSON)(jsonPath, formatPersistedData(persistedData));
    }
};
exports.processOptions = processOptions;
